from revscoring.features import (
    diff, page, parent_revision, previous_user_revision, revision, user
)
from revscoring.features.modifiers import log
from . import generic

damaging = generic.damaging
good_faith = generic.good_faith

